@@ -1,7 +1,7 @@
 /*
  *  chart.c: high level chart graphics generator
  *
- *  Copyright (C) 1997-2005 John Coppens (john@jcoppens.com)
+ *  Copyright (C) 1997- John Coppens (john@jcoppens.com)
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -665,8 +665,8 @@ add_line_to_list(el_definition *el, complex prev_imp, double f)
       wl = 300000 * el->vf / f;		// milimeters
   }
 
-  switch (el->typ) {
-    case ELT_CAP:		// R is constant here.
+  switch (el->typ) {			// R is constant here
+    case ELT_CAP:
     case ELT_IND:
     case ELT_PARLC:
     case ELT_SERLC:
@@ -683,7 +683,8 @@ add_line_to_list(el_definition *el, complex prev_imp, double f)
       }
       switch (el->conn) {
         case ELC_SERIES:
-          setlinestyle(&ln->group, 1, pref.arc_color[Z_ARC]);
+          setlinestyle(&ln->group, pref.arc_size[Z_ARC], 
+				   pref.arc_color[Z_ARC]);
           ln->line = rg_arc(&ln->group, imp1, imp2, pref.chart_z0, imp_mode);
           if (plot_dest == DST_PRINT) {
             print_setlinestyle(pref.prt_arc_size[Z_ARC],
@@ -692,7 +693,9 @@ add_line_to_list(el_definition *el, complex prev_imp, double f)
           }
           break;
         case ELC_PARALLEL:
-          setlinestyle(&ln->group, 1, pref.arc_color[Y_ARC]);
+          setlinestyle(&ln->group,
+		       pref.arc_size[Y_ARC],
+		       pref.arc_color[Y_ARC]);
           ln->line = rg_arc(&ln->group, reciprocal(imp2), reciprocal(imp1),
 		pref.chart_z0, !imp_mode);
           if (plot_dest == DST_PRINT) {
@@ -705,7 +708,9 @@ add_line_to_list(el_definition *el, complex prev_imp, double f)
         }
       break;
     case ELT_LINE:
-      setlinestyle(&ln->group, 1, pref.arc_color[K_ARC]);
+      setlinestyle(&ln->group, 
+		   pref.arc_size[K_ARC], 
+		   pref.arc_color[K_ARC]);
       if (imp_mode)
         ln->line = k_arc(&ln->group, act_imp, prev_imp, el->z0);
       else
@@ -722,7 +727,9 @@ add_line_to_list(el_definition *el, complex prev_imp, double f)
       }
       break;
     case ELT_ZY:
-      setlinestyle(&ln->group, 1, pref.arc_color[ZY_LINE]);
+      setlinestyle(&ln->group, 
+		   pref.arc_size[ZY_LINE], 
+		   pref.arc_color[ZY_LINE]);
       ln->line = zy_line(&ln->group, act_imp);
       if (plot_dest == DST_PRINT) {
         print_setlinestyle(pref.prt_arc_size[ZY_LINE],
@@ -925,7 +932,7 @@ do_arc(GnomeCanvasGroup **grp,
 		gnome_canvas_line_get_type(),
 		"points", points,
 		"fill_color_rgba", last_color,
-		"width_pixels", 1,
+		"width_pixels", (int) last_lw,
 		NULL);
   gnome_canvas_points_unref(points);
  
