@@ -1,7 +1,7 @@
 /*
  *  confmgr.c: configuration manager
  *
- *  Copyright (C) 1997-2005 John Coppens (john@jcoppens.com)
+ *  Copyright (C) 1997- John Coppens (john@jcoppens.com)
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -29,8 +29,59 @@
 #include "global.h"
 #include "support.h"
 
+char *
+combo_box_get_active_text(GtkComboBox *cbbox)
+{
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+  int active;
+  char *size;
+  
+  active = gtk_combo_box_get_active(cbbox);
+  if (active < 0)
+    return NULL;
+    
+  model = gtk_combo_box_get_model(cbbox);
+  gtk_tree_model_iter_nth_child(model, &iter, NULL, active);
+  gtk_tree_model_get(model, &iter,
+                1, &size,                       // The 'internal' formal name
+                -1);
+  return size;
+}
+
+int
+combo_box_set_active_text(GtkComboBox *cbbox, char *str)
+{
+  GtkTreeModel *model;
+  GtkTreeIter iter;
+  gboolean ok;
+  int found, elnr;
+  char *size;
+
+  if (!str || (strlen(str) == 0))
+    return -1;
+
+  model = gtk_combo_box_get_model(cbbox);
+  found = 0; elnr = 0;
+  ok = gtk_tree_model_get_iter_first(model, &iter);
+  while (ok) {
+    gtk_tree_model_get(model, &iter,
+                1, &size,                       // This is the 'internal' name
+                -1);
+    if (strcmp(size, str) == 0) {
+      found = elnr;
+      g_free(size);
+      break;
+    }
+    g_free(size);
+    elnr++;
+    ok = gtk_tree_model_iter_next(model, &iter);
+  }
+  gtk_combo_box_set_active(cbbox, found);
+}
+
 void
-parse_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
+parse_widget_by_table(conf_definition *tbl, GtkWidget *ref)
 {
   GtkWidget *w;
   GList *glst;
@@ -39,7 +90,8 @@ parse_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
   int d, nr;
   guint16 alpha;
 
-  for (d = 0; d < len; d++) {
+  for (d = 0; tbl[d].typ != CFM_W_LAST; d++) {
+    printf("%d\n", d);
     w = lookup_widget(ref, tbl[d].wdg);
     switch (tbl[d].typ) {
       case CFM_W_CBTN: 
@@ -89,6 +141,10 @@ parse_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
 	  *(int *)tbl[d].data =
 		  gtk_combo_box_get_active(GTK_COMBO_BOX(w));
 	  break;
+      case CFM_W_COMBOBOX_STR:
+          tbl[d].data =
+                  combo_box_get_active_text(GTK_COMBO_BOX(w));
+          break;
       case CFM_W_CLIST:
           glst = *(GList **)tbl[d].data;
           if (glst != NULL) {
@@ -120,7 +176,7 @@ parse_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
 
 
 void
-load_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
+load_widget_by_table(conf_definition *tbl, GtkWidget *ref)
 {
   GtkWidget *w;
   GList *glst;
@@ -130,7 +186,7 @@ load_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
   double val;
   char bff[15], *str[1], *p;
 
-  for (d = 0; d < len; d++) {
+  for (d = 0; tbl[d].typ != CFM_W_LAST; d++) {
     w = lookup_widget(ref, tbl[d].wdg);
     switch (tbl[d].typ) {
       case CFM_W_CBTN: 
@@ -185,6 +241,9 @@ load_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
       case CFM_W_CBOX:
 	  gtk_combo_box_set_active(GTK_COMBO_BOX(w), *(char *)tbl[d].data);
 	  break;
+      case CFM_W_COMBOBOX_STR:
+	  combo_box_set_active_text(GTK_COMBO_BOX(w), (char *)tbl[d].data);
+	  break;
       case CFM_W_CLIST:
           glst = *(GList **)tbl[d].data;
           for (nr = 0; nr < g_list_length(glst); nr++) {
@@ -210,13 +269,13 @@ load_widget_by_table(conf_definition *tbl, int len, GtkWidget *ref)
 
 
 gboolean
-save_by_table(char *fn, conf_definition *tbl, int len)
+save_by_table(char *fn, conf_definition *tbl)
 {
   char path[120], path2[140];
   int d, nr;
   GList *glst;
 
-  for (d = 0; d < len; d++) {
+  for (d = 0; tbl[d].typ != CFM_W_LAST; d++) {
     if (fn != NULL)
       sprintf(path, "=%s=/%s", fn, tbl[d].key);
     else
@@ -254,14 +313,14 @@ save_by_table(char *fn, conf_definition *tbl, int len)
 }
 
 void
-load_by_table(char *fn, conf_definition *tbl, int len)
+load_by_table(char *fn, conf_definition *tbl)
 {
   GList *glst;
   char path[120], path2[140], *p;
   int def;
   int d, nr, llen, v;
 
-  for (d = 0; d < len; d++) {
+  for (d = 0; tbl[d].typ != CFM_W_LAST; d++) {
     if (fn != NULL)
       sprintf(path, "=%s=/%s", fn, tbl[d].key);
     else
@@ -270,19 +329,21 @@ load_by_table(char *fn, conf_definition *tbl, int len)
     switch (tbl[d].styp) {
       case CFM_T_STR: 
           sprintf(path2, "%s=%s", path, tbl[d].def);
-          strcpy((char *)tbl[d].data,
-                 gnome_config_get_string_with_default(path2, &def));
+           
+	  p = gnome_config_get_string_with_default(path2, &def);
+          strcpy(tbl[d].data, p);
+          g_free(p);
           break;
       case CFM_T_INT: 
-          sscanf(tbl[d].def, "%i", &v);
+          v = strtol(tbl[d].def, NULL, 0);
           sprintf(path2, "%s=%ld", path, v);
           *(int *)tbl[d].data =
-                          gnome_config_get_int_with_default(path2, &def);
+		gnome_config_get_int_with_default(path2, &def);
           break;
       case CFM_T_CHAR:
           sprintf(path2, "%s=%s", path, tbl[d].def);
           *(char *)tbl[d].data =
-                          gnome_config_get_int_with_default(path2, &def);
+		gnome_config_get_int_with_default(path2, &def);
           break;
       case CFM_T_FLOAT: 
           sprintf(path2, "%s=%s", path, tbl[d].def);
