@@ -41,108 +41,6 @@ static  int scale_timer_id = -1;
 
 enum {ENTRY_VALID, ENTRY_INVALID, ENTRY_SET};
 
-typedef struct {
-  char *name;
-  double z0, vf, db1, mhz1, db2, mhz2;
-} cabletable_entry;
-
-cabletable_entry cabletable[] = {
-  {N_("RG-5/U"),	52.5, 0.659,  0.77,  10.0,  2.90, 100.0},
-  {N_("RG-5B/U"), 	50.0, 0.659,  0.66,  10.0,  2.40, 100.0},           
-  {N_("RG-6A/U"), 	75.0, 0.659,  0.78,  10.0,  2.90, 100.0},           
-  {N_("RG-6 Foam"),     75.0, 0.780,  5.30,  50.0, 16.20, 500.0},
-  {N_("RG-8A/U"), 	50.0, 0.659,  0.55,  10.0,  2.00, 100.0},           
-  {N_("RG-8 foam"),	50.0, 0.800,  1.70, 100.0,  6.0, 1000.0},
-  {N_("RG-9/U"), 	51.0, 0.659,  0.57,  10.0,  2.00, 100.0},           
-  {N_("RG-9B/U"), 	50.0, 0.659,  0.61,  10.0,  2.10, 100.0},           
-  {N_("RG-10A/U"), 	50.0, 0.659,  0.55,  10.0,  2.00, 100.0},           
-  {N_("RG-11A/U"), 	75.0, 0.660,  0.70,  10.0,  2.30, 100.0},           
-  {N_("RG-11 foam"),	75.0, 0.780,  3.30,  50.0, 12.10, 500.0},
-  {N_("RG-12A/U"), 	75.0, 0.659,  0.66,  10.0,  2.30, 100.0},           
-  {N_("RG-13A/U"), 	75.0, 0.659,  0.66,  10.0,  2.30, 100.0},           
-  {N_("RG-14A/U"), 	50.0, 0.659,  0.41,  10.0,  1.40, 100.0},           
-  {N_("RG-16A/U"), 	52.0, 0.670,  0.40,  10.0,  1.20, 100.0},           
-  {N_("RG-17A/U"), 	50.0, 0.659,  0.23,  10.0,  0.80, 100.0},           
-  {N_("RG-18A/U"), 	50.0, 0.659,  0.23,  10.0,  0.80, 100.0},           
-  {N_("RG-19A/U"), 	50.0, 0.659,  0.17,  10.0,  0.68, 100.0},           
-  {N_("RG-20A/U"), 	50.0, 0.659,  0.17,  10.0,  0.68, 100.0},           
-  {N_("RG-21A/U"), 	50.0, 0.659,  4.40,  10.0, 13.00, 100.0},           
-  {N_("RG-29/U"), 	53.5, 0.659,  1.20,  10.0,  4.40, 100.0},           
-  {N_("RG-34A/U"), 	75.0, 0.659,  0.29,  10.0,  1.30, 100.0},           
-  {N_("RG-34B/U"), 	75.0, 0.660,  0.30,  10.0,  1.40, 100.0},           
-  {N_("RG-35A/U"), 	75.0, 0.659,  0.24,  10.0,  0.85, 100.0},           
-  {N_("RG-54A/U"), 	58.0, 0.659,  0.74,  10.0,  3.10, 100.0},           
-  {N_("RG-55B/U"), 	53.5, 0.659,  1.30,  10.0,  4.80, 100.0},           
-  {N_("RG-55A/U"), 	50.0, 0.659,  1.30,  10.0,  4.80, 100.0},           
-  {N_("RG-58/U"), 	53.5, 0.660,  1.25,  10.0,  4.65, 100.0},           
-  {N_("RG-58A/U"), 	53.5, 0.659,  1.25,  10.0,  4.65, 100.0},           
-  {N_("RG-58C/U"), 	50.0, 0.659,  1.40,  10.0,  4.90, 100.0},           
-  {N_("RG-58 foam"),	53.5, 0.790,  3.80, 100.0,  6.0,  300.0},
-  {N_("RG-59A/U"), 	75.0, 0.659,  1.10,  10.0,  3.40, 100.0},           
-  {N_("RG-59B/U"), 	75.0, 0.660,  1.10,  10.0,  3.40, 100.0},           
-  {N_("RG-59 foam"),	75.0, 0.790,  3.80, 100.0,  6.0,  300.0},
-  {N_("RG-62A/U"), 	93.0, 0.840,  0.85,  10.0,  2.70, 100.0},           
-  {N_("RG-74A/U"), 	50.0, 0.659,  0.38,  10.0,  1.50, 100.0},           
-  {N_("RG-83/U"), 	35.0, 0.660,  0.80,  10.0,  2.80, 100.0},           
-  {N_("RG-174A/"), 	50.0, 0.660,  3.40,  10.0, 10.60, 100.0},           
-  {N_("RG-213/U"), 	50.0, 0.660,  0.60,  10.0,  1.90, 100.0},           
-  {N_("RG-218/U"), 	50.0, 0.660,  0.20,  10.0,  1.00, 100.0},           
-  {N_("RG-220/U"), 	50.0, 0.660,  0.20,  10.0,  0.70, 100.0},
-  {N_("UR-43"),		52.0, 0.660,  1.30,  10.0,  4.3,  100.0},
-  {N_("UR-57"),		75.0, 0.660,  0.60,  10.0,  1.9,  100.0},
-  {N_("UR-63"), 	75.0, 0.960,  0.15,  10.0,  0.5,  100.0},
-  {N_("UR-67"), 	50.0, 0.660,  0.60,  10.0,  2.0,  100.0},
-  {N_("UR-70"), 	75.0, 0.660,  1.50,  10.0,  4.9,  100.0},
-  {N_("UR-74"), 	51.0, 0.660,  0.30,  10.0,  1.0,  100.0},
-  {N_("UR-76"), 	51.0, 0.660,  1.60,  10.0,  5.3,  100.0},
-  {N_("UR-77"), 	75.0, 0.660,  0.30,  10.0,  1.0,  100.0},
-  {N_("UR-79"), 	50.0, 0.960,  0.16,  10.0,  0.5,  100.0},
-  {N_("UR-83"), 	50.0, 0.960,  0.25,  10.0,  0.8,  100.0},
-  {N_("UR-85"), 	75.0, 0.960,  0.20,  10.0,  0.7,  100.0},
-  {N_("UR-90"), 	75.0, 0.660,  1.10,  10.0,  3.5,  100.0},
-  {N_("UR-95"), 	50.0, 0.660,  2.60,  10.0,  8.2,  100.0},
-  {N_("Belden 8240"),	50.0, 0.660,  4.90, 100.0, 20.0, 1000.0},
-  {N_("Belden 8267"),   50.0, 0.660,  2.20, 100.0,  8.0, 1000.0},
-  {N_("Belden 8208"),   50.0, 0.660,  0.00,   0.0,  8.0, 1000.0},
-  {N_("Belden 9258"),   50.0, 0.780,  3.70, 100.0, 12.8, 1000.0},
-  {N_("Belden 9880"),   50.0, 0.820,  1.30, 100.0,  4.5, 1000.0},
-  {N_("Belden 9913"),   50.0, 0.820,  1.30, 100.0,  4.5, 1000.0},
-  {N_("Belden 9914"),   50.0, 0.660,  0.00,   0.0,  9.0, 1000.0}
-};
-#define ctable_len (sizeof(cabletable)/sizeof(cabletable_entry))
-
-typedef struct {
-  char *title;
-  int width;
-} cable_col;
-
-cable_col cablecol[] = {
-  {"Cable type", 120},
-  {"Zo.", 40},
-  {"Vf", 40},
-  {"dB @", 50},
-  {"MHz", 60},
-  {"dB @", 50},
-  {"MHz", 60}
-};
-#define cablecol_len (sizeof(cablecol)/sizeof(cable_col))
-
-char *stub_entries[] = {
-  "comp_stub_vf_entry",
-  "comp_stub_l1_entry",
-  "comp_stub_f1_entry",
-  "comp_stub_l2_entry",
-  "comp_stub_f2_entry"
-};
-
-char *line_entries[] = {
-  "comp_line_vf_entry",
-  "comp_line_l1_entry",
-  "comp_line_f1_entry",
-  "comp_line_l2_entry",
-  "comp_line_f2_entry"
-};
-
 //	Scale/entry pair definitions
 
 typedef struct {
@@ -364,107 +262,6 @@ xml_file_loaded(xmlDocPtr *doc, const char *fname, char *title)
 }
 
 
-void
-load_cable_table(GtkWidget *ref)
-{
-  int i;
-  char z0[10], vf[8], db1[10], db2[10], mhz1[12], mhz2[12];
-  GtkListStore *cables;
-  GtkTreeView *cbl_view;
-  GtkTreeViewColumn *col;
-  GtkTreeIter iter;
-  GtkCellRenderer *renderer;
-  
-  cables = gtk_list_store_new(cablecol_len+1,
-	G_TYPE_STRING,			// Cable name
-	G_TYPE_STRING,			// z0
-	G_TYPE_STRING,			// vf
-	G_TYPE_STRING,			// db1
-	G_TYPE_STRING,			// mhz1
-	G_TYPE_STRING,			// db2
-	G_TYPE_STRING,			// mhz2
-	G_TYPE_INT);			// Nr in table
-
-  cbl_view = GTK_TREE_VIEW(lookup_widget(ref, "cable_view"));
-  gtk_tree_view_set_model(cbl_view,  GTK_TREE_MODEL(cables));
-  g_object_unref(G_OBJECT(cables));
-
-  for (i = 0; i < cablecol_len; i++) {
-    renderer = gtk_cell_renderer_text_new();
-    gtk_object_set(GTK_OBJECT(renderer),
-		"height", 16,
-		"xalign", (i==0 ? 0.0 : 1.0),
-		NULL);
-    col = gtk_tree_view_column_new_with_attributes(cablecol[i].title,
-	renderer, "text", i, NULL);
-    gtk_tree_view_append_column(cbl_view, col);
-    gtk_tree_view_column_set_sizing(col, GTK_TREE_VIEW_COLUMN_FIXED);
-    gtk_tree_view_column_set_fixed_width(col, cablecol[i].width);
-  }
-
-  for (i = 0; i < ctable_len; i++) {
-    gtk_list_store_append(cables, &iter);
-    sprintf(z0, "%.1f", cabletable[i].z0);
-    sprintf(vf, "%.3f", cabletable[i].vf);
-    sprintf(db1, "%.2f", cabletable[i].db1);
-    sprintf(mhz1, "%.0f", cabletable[i].mhz1);
-    sprintf(db2, "%.2f", cabletable[i].db2);
-    sprintf(mhz2, "%.0f", cabletable[i].mhz2);
-    gtk_list_store_set(cables, &iter,
-		0, cabletable[i].name,
-		1, z0,
-		2, vf,
-		3, db1,
-		4, mhz1,
-		5, db2,
-		6, mhz2,
-		7, i,
-		-1);
-  }
-}
-
-
-void
-show_cable_data(int which, int c)
-{
-  GtkWidget *w;
-  int d;
-  char **entbl, bff[15];
-  
-  switch (which) {
-    case SEP_STUB_VAL: 
-      entbl = stub_entries;
-      scale_entry_pair_set(SEP_STUB_Z0, cabletable[c].z0);
-      break;
-    case SEP_LINE_VAL:
-      entbl = line_entries;
-      scale_entry_pair_set(SEP_LINE_Z0, cabletable[c].z0);
-      break;
-  }
-      
-  for (d = 0; d < 5; d++) {
-    switch (d) {
-      case 0: sprintf(bff, "%.3f", cabletable[c].vf); break;
-      case 1: sprintf(bff, "%.2f", cabletable[c].db1); break;
-      case 2: sprintf(bff, "%.0f", cabletable[c].mhz1); break;
-      case 3: sprintf(bff, "%.2f", cabletable[c].db2); break;
-      case 4: sprintf(bff, "%.0f", cabletable[c].mhz2); break;
-    }
-    w = lookup_widget(MainWindow, entbl[d]);
-    gtk_entry_set_text(GTK_ENTRY(w), bff);
-  }
-}
-
-/*
- *	These routines manage the component selection and connection
- *	type.
- */
-
-/*	Load the element callbacks and set the button icon, from the
- *	table supplied.
- *	Used for the connection type and element buttons.
- */
-
 void
 load_element_toggles(toggle_button_def *tbl, int len, GCallback cb)
 {
@@ -480,10 +277,10 @@ load_element_toggles(toggle_button_def *tbl, int len, GCallback cb)
     tbl[c].wdg = lookup_widget(MainWindow, bff);
 
     tbl[c].id = g_signal_connect(G_OBJECT(tbl[c].wdg), "clicked", cb,
-			GINT_TO_POINTER(c));
+                GINT_TO_POINTER(c));
 
     tbl[c].pxb = gdk_pixbuf_new_from_inline(tbl[c].size, tbl[c].def, 
-			FALSE, NULL);
+                FALSE, NULL);
     gtk_image_set_from_pixbuf(GTK_IMAGE(tb_img), tbl[c].pxb);
   }
 }
